MethodChannelAppstackPlugin class

An implementation of AppstackPluginPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(String apiKey, int logLevel, String? customerUserId) → Future<void>
Configure Appstack SDK with your API key and optional parameters
override
deleteUserData() → Future<void>
Permanently delete the current user's Appstack data.
override
enableAppleAdsAttribution() → Future<bool>
Enable Apple Search Ads Attribution tracking (iOS only)
override
getAppstackId() → Future<String?>
Get the Appstack ID for the current user
override
getAttributionParams() → Future<Map<String, dynamic>?>
Get attribution parameters
override
getAttributionParamsWithCallback() → Stream<Map<String, dynamic>?>
Get attribution parameters via a background-native stream
override
override
isSdkDisabled() → Future<bool>
Check if the SDK is disabled
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvent(String eventType, String? eventName, Map<String, dynamic>? parameters) → Future<bool>
Send an event with optional parameters
override
setCustomerUserId(String? customerUserId) → Future<void>
Set — or clear — the customer user id after configure
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited